// Basic buildah operations for container management
use std::process::Command;


/// Execute a buildah command and return the result
pub fn execute_buildah_command(args: &[&str]) -> Dynamic {
    let output = Command::new("buildah")
        .args(args)
        .output();
    
    match output {
        Ok(output) => {
            let stdout = String::from_utf8_lossy(&output.stdout).to_string();
            let stderr = String::from_utf8_lossy(&output.stderr).to_string();
            
            let result = CommandResult {
                stdout,
                stderr,
                success: output.status.success(),
                code: output.status.code().unwrap_or(-1),
            };
            
            result.to_dynamic()
        },
        Err(e) => {
            CommandResult::error(&format!("Failed to execute buildah command: {}", e)).to_dynamic()
        }
    }
}
